==> lxqt-panel-1.4.0.tar.xz: lxqt-panel-1.4.0/plugin-cpuload/translations/cpuload_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Orokorra</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Erakutsi testua</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Eguneratze-tartea:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>seg</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Barraren orientazioa:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>Behetik gora</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>Goitik behera</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>Ezkerretik eskuinera</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>Eskuinetik ezkerrera</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-cpuload/translations/cpuload_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>CPU karga %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>CPUaren kargaren ezarpenak</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Orokorra</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Erakutsi testua</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Eguneratze-tartea:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>seg</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Barraren orientazioa:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Barraren zabalera:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>Behetik gora</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>Goitik behera</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>Ezkerretik eskuinera</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>Eskuinetik ezkerrera</translation>
    </message>
</context>
</TS>
